==> org.hl7.fhir.r4-6.0.1-sources.jar: org/hl7/fhir/r4/model/CanonicalType.java <==
package org.hl7.fhir.r4.model;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
    
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
 */



import java.net.URI;

import ca.uhn.fhir.model.api.annotation.DatatypeDef;

/**
 * Primitive type "canonical" in FHIR: an OID represented as urn:oid:0.1.2.3.4...
 */
@DatatypeDef(name="canonical", profileOf=UriType.class)
public class CanonicalType extends UriType {

	private static final long serialVersionUID = 4L;

	/**
	 * Constructor
	 */
	public CanonicalType() {
		super();
	}

	/**
	 * Constructor
	 */
	public CanonicalType(String theValue) {
		super(theValue);
	}

	/**
	 * Constructor
	 */
	public CanonicalType(URI theValue) {
		super(theValue);
	}

	/**
	 * Constructor
	 */
	@Override
	public CanonicalType copy() {
		CanonicalType ret = new CanonicalType(getValue());
    copyValues(ret);
    return ret;
	}

	public String fhirType() {
		return "canonical";		
	}
	

}

==> org.hl7.fhir.r4-6.3.23-sources.jar: org/hl7/fhir/r4/model/CanonicalType.java <==
package org.hl7.fhir.r4.model;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
    
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
 */

import java.net.URI;

import ca.uhn.fhir.model.api.annotation.DatatypeDef;

/**
 * Primitive type "canonical" in FHIR: an OID represented as
 * urn:oid:0.1.2.3.4...
 */
@DatatypeDef(name = "canonical", profileOf = UriType.class)
public class CanonicalType extends UriType {

  private static final long serialVersionUID = 4L;

  /**
   * Constructor
   */
  public CanonicalType() {
    super();
  }

  /**
   * Constructor
   */
  public CanonicalType(String theValue) {
    super(theValue);
  }

  /**
   * Constructor
   */
  public CanonicalType(URI theValue) {
    super(theValue);
  }

  /**
   * Constructor
   */
  @Override
  public CanonicalType copy() {
    CanonicalType ret = new CanonicalType(getValue());
    copyValues(ret);
    return ret;
  }

  public String fhirType() {
    return "canonical";
  }

}
